# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import account_invoice
from . import account_move_line
from . import product
from . import purchase
from . import res_config_settings
from . import res_partner
from . import res_company
from . import stock
from . import stock_move
from . import stock_rule
